==> apache-asterixdb-0.9.8-source-release.zip: apache-asterixdb-0.9.8/asterix-lang-common/src/main/java/org/apache/asterix/lang/common/statement/DataverseDropStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.lang.common.statement;

import org.apache.asterix.common.exceptions.CompilationException;
import org.apache.asterix.common.metadata.DataverseName;
import org.apache.asterix.lang.common.base.AbstractStatement;
import org.apache.asterix.lang.common.base.Statement;
import org.apache.asterix.lang.common.visitor.base.ILangVisitor;

public class DataverseDropStatement extends AbstractStatement {

    private DataverseName dataverseName;
    private boolean ifExists;
    private boolean ifEmpty;

    public DataverseDropStatement(DataverseName dataverseName, boolean ifExists) {
        this(dataverseName, ifExists, false);
    }

    public DataverseDropStatement(DataverseName dataverseName, boolean ifExists, boolean ifEmpty) {
        this.dataverseName = dataverseName;
        this.ifExists = ifExists;
        this.ifEmpty = ifEmpty;
    }

    @Override
    public Kind getKind() {
        return Statement.Kind.DATAVERSE_DROP;
    }

    public DataverseName getDataverseName() {
        return dataverseName;
    }

    public boolean getIfExists() {
        return ifExists;
    }

    public boolean getIfEmpty() {
        return ifEmpty;
    }

    @Override
    public <R, T> R accept(ILangVisitor<R, T> visitor, T arg) throws CompilationException {
        return visitor.visit(this, arg);
    }

    @Override
    public byte getCategory() {
        return Category.DDL;
    }

}

==> apache-asterixdb-0.9.9-source-release.zip: apache-asterixdb-0.9.9/asterix-lang-common/src/main/java/org/apache/asterix/lang/common/statement/DataverseDropStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.lang.common.statement;

import java.util.Objects;

import org.apache.asterix.common.exceptions.CompilationException;
import org.apache.asterix.common.metadata.DataverseName;
import org.apache.asterix.common.metadata.Namespace;
import org.apache.asterix.lang.common.base.AbstractStatement;
import org.apache.asterix.lang.common.base.Statement;
import org.apache.asterix.lang.common.visitor.base.ILangVisitor;

public class DataverseDropStatement extends AbstractStatement {

    private final Namespace namespace;
    private final boolean ifExists;
    private final boolean ifEmpty;

    public DataverseDropStatement(Namespace namespace, boolean ifExists) {
        this(namespace, ifExists, false);
    }

    public DataverseDropStatement(Namespace namespace, boolean ifExists, boolean ifEmpty) {
        this.namespace = Objects.requireNonNull(namespace);
        this.ifExists = ifExists;
        this.ifEmpty = ifEmpty;
    }

    @Override
    public Kind getKind() {
        return Statement.Kind.DATAVERSE_DROP;
    }

    public Namespace getNamespace() {
        return namespace;
    }

    public String getDatabaseName() {
        return namespace.getDatabaseName();
    }

    public DataverseName getDataverseName() {
        return namespace == null ? null : namespace.getDataverseName();
    }

    public boolean getIfExists() {
        return ifExists;
    }

    public boolean getIfEmpty() {
        return ifEmpty;
    }

    @Override
    public <R, T> R accept(ILangVisitor<R, T> visitor, T arg) throws CompilationException {
        return visitor.visit(this, arg);
    }

    @Override
    public byte getCategory() {
        return Category.DDL;
    }

}
